#
# spec file for package cli11
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cli11
Version:        2.4.2
Release:        1.5
Summary:        Command line parser for C++11
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/CLIUtils/CLI11
Source:         %{name}-%{version}.tar.gz
BuildRequires:  Catch2-devel
BuildRequires:  boost-devel
BuildRequires:  cmake >= 3.5
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  python3-devel

%description
CLI11 is a command line parser for C++11 and beyond that provides a
rich feature set.

%package devel
Summary:        Development files for CLI11
BuildArch:      noarch

%description devel
CLI11 is a command line parser for C++11 and beyond that provides a
rich feature set. It is header only, and has a number of design
limits by choice:

 * No completion of partial options (like --ve for --version,
   if it were unambiguous)
 * No wide strings/Unicode

%package      doc
Summary:        Documentation for CLI11
Group:          Documentation/Other
BuildArch:      noarch

%description  doc
This package contains documentation for CLI11

CLI11 is a command line parser for C++11 and beyond that provides a
rich feature set. It is header only, and has a number of design
limits by choice:

 * No completion of partial options (like --ve for --version,
   if it were unambiguous)
 * No wide strings/Unicode

%prep
%autosetup -p1

%build
%cmake \
%if 0%{?sle_version} <= 150300 && 0%{?suse_version} <= 1500
  -DCLI11_BUILD_TESTS:BOOL=FALSE \
%else
  -DCLI11_BUILD_TESTS:BOOL=TRUE \
%endif
  -DCLI11_BUILD_DOCS:BOOL=TRUE \
  -DCLI11_BUILD_EXAMPLES:BOOL=FALSE
%cmake_build all docs

%install
%cmake_install

%check
%ctest

%files devel
%license LICENSE
%doc CHANGELOG.md
%dir %{_includedir}/CLI
%dir %{_includedir}/CLI/impl
%{_includedir}/CLI/*.hpp
%{_includedir}/CLI/impl/*.hpp
%dir %{_datadir}/cmake/CLI11/
%{_datadir}/cmake/CLI11/*.cmake
%{_datadir}/pkgconfig/CLI11.pc

%files doc
%doc build/docs/html/

%changelog
* Thu Aug  1 2024 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 2.4.2:
  This version improves support for alternative build systems, like
  Meson and Bazel. The single-include file now is in its own
  subdirectory. Several smaller fixes as well.
  + Meson: fixes, cleanups, and modernizations #1024 & #1025
  + Support building with Bazel #1033
  + Restore non-arch dependent path for the pkgconfig file #1012
  + Add get_subcommand_no_throw #1016
  + Move single file to single-include folder #1030 & #1036
  + Fixed app.set_failure_message(...) -> app.failure_message(...) #1018
  + Add IWYU pragmas #1008
  + Fix internal header include paths #1011
  + Improved clarity in RequiredError #1029
  + Added ability to use lexical_cast overloads constrained with enable_if #1021
  + Bug fixes in latest release related to environmental variable
    parsing from option groups and unrecognized fields in a config file #1005
- Packaging:
  + move cli11.pc to _datadir
  + change -devel package to build noarch
* Fri Mar 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.1:
  * Bugfix: Include cstdint (gh#CLIUtils/CLI11#996).
  * Bugfix: Fix change in operation of config_ptr with unused
    default in the count method (gh#CLIUtils/CLI11#1003).
  * Tests: Include libatomic if required for fuzzing test
    (gh#CLIUtils/CLI11#1000).
- Changes from version 2.4.0:
  * Add Unicode support and bug fixes (gh#CLIUtils/CLI11#804,
    gh#CLIUtils/CLI11#923, gh#CLIUtils/CLI11#876,
    gh#CLIUtils/CLI11#848, gh#CLIUtils/CLI11#832,
    gh#CLIUtils/CLI11#987).
  * Match TOML standard for string and numerical entries,
    multiline strings (gh#CLIUtils/CLI11#968,
    gh#CLIUtils/CLI11#967,gh#CLIUtils/CLI11#964,
    gh#CLIUtils/CLI11#935).
  * Add validation for environmental variables
    (gh#CLIUtils/CLI11#926).
  * Add an escape string transform (gh#CLIUtils/CLI11#970).
  * Add A REVERSE multi-option policy to support multiple config
    files and other applications (gh#CLIUtils/CLI11#918).
  * Add usage message replacement (gh#CLIUtils/CLI11#768).
  * Allow using dot notation for subcommand arguments such as
  - -sub1.field (gh#CLIUtils/CLI11#789).
  * Bugfix: Fuzzing tests and fixes (gh#CLIUtils/CLI11#930,
    gh#CLIUtils/CLI11#905, gh#CLIUtils/CLI11#874,
    gh#CLIUtils/CLI11#846).
  * Bugfix: Missing coverage tests (gh#CLIUtils/CLI11#928).
  * Bugfix: CMake package and package config tests and fixes
    (gh#CLIUtils/CLI11#916).
  * Bugfix: Environmental variable checks in non-triggered
    subcommands (gh#CLIUtils/CLI11#904).
  * Bugfix: Environmental variables were not being correctly
    process by config pointer (gh#CLIUtils/CLI11#891).
  * Bugfix: Undefined behavior in sum_string_vector
    (gh#CLIUtils/CLI11#893).
  * Bugfix: Warnings and updates for CUDA 11 support
    (gh#CLIUtils/CLI11#851).
  * Backend: Add tests for newer compilers (lost with Travis CI)
    (gh#CLIUtils/CLI11#972).
  * Backend: Increase minimum CMake to 3.5
    (gh#CLIUtils/CLI11#898).
  * Backend: Remove integrated Conan support (provided now by
    Conan center) (gh#CLIUtils/CLI11#853).
  * Tests: Support Catch2 Version 3 (gh#CLIUtils/CLI11#896,
    gh#CLIUtils/CLI11#980).
- Package is no longer noarch as it installs pkgconfig file to
  %%_libdir.
- Drop conditionals supporting EOL openSUSE versions.
* Sat Jan  7 2023 Haochuan Chen <haochuan.chen@univ-lorraine.fr>
- Update to version 2.3.2:
  * Bugfix: Consistently use ADL for lexical_cast, making it easier to extend for custom template types #820
  * Bugfix: Tweak the parsing of files for flags with disable_flag_override #800]
  * Bugfix: Handle out of bounds long long #807
  * Bugfix: Spacing of make_description min option output #808
  * Bugfix: Print last parsed subcommand's help message #822
  * Bugfix: Avoid floating point warning in GCC 12 #803
  * Bugfix: Fix a few gcc warnings #813
  * Backend: Max CMake tested 3.22 -> 3.24 #823
- Update to version 2.3.1:
  * Bugfix: App::get_option_group implementation missing #793
  * Bugfix: Fix spacing when setting an empty footer #796
  * Bugfix: Address Klocwork static analysis checking issues #785
* Mon Oct 24 2022 Haochuan Chen <haochuan.chen@univ-lorraine.fr>
- Disable tests for %%{?sle_version} <= 150300 due to possible issues of old
  cmake versions
* Mon Oct 24 2022 Haochuan Chen <haochuan.chen@univ-lorraine.fr>
- Although the pre-compiled mode has been introduced upstream, it is still not
  able to build shared libs, so CLI11_PRECOMPILED is default to be disabled.
  The package is then still header-only, and the build architecture is changed
  to noarch.
- Tests are enabled during building.
- Upstream changes: update to version 2.3.0
  * Add CLI11_PRECOMPILED as an option. #762
  * Bugfix: Include <functional> in FormatterFwd #727
  * Bugfix: Add missing Macros.hpp to Error.hpp #755
  * Bugfix: Fix subcommand callback trigger #733
  * Bugfix: Variable rename to avoid warning #734
  * Bugfix: split_program_name single file name error #740
  * Bugfix: Better support for min/max overrides on MSVC #741
  * Bugfix: Support MSVC 2022 #748
  * Bugfix: Support negated flag in config file #775
  * Bugfix: Better errors for some confusing config file situations #781
  * Backend: Restore coverage testing (lost with Travis CI) #747
* Wed Apr 13 2022 Haochuan Chen <yjcoshc@mail.nankai.edu.cn>
- Update to version 2.2.0
  * Add `MultiOptionPolicy::Sum`  and refactor the `add_flag` to fix a bug when using `std::optional<bool>` as type.
  * Add support for an empty vector result in TOML and as a default string.
  * Add `.validate_optional_arguments()` to support discriminating positional arguments from vector option arguments.
  * Add `CLI::FileOnDefaultPath` to check for files on a specified default path.
  * Change default value display in help messages from `=XXXX` to `[XXXXX]` to make it clearer.
  * Modify the Range Validator to support additional types and clean up the error output.
  * Bugfix: The trigger on parse modifier did not work on positional argument.s
  * Bugfix: The single header file generation was missing custom namespace generation.
  * Bugfix: Clean up File Error handling in the argument processing.
  * Bugfix: Fix a stack overflow error if nameless commands had fallthrough.
  * Bugfix: A subcommand callback could be executed multiple times if it was a member of an option group.
  * Bugfix: Fix an issue with vectors of multi argument types where partial argument sets did not result in an error.
  * Bugfix: Fix an issue with type the template matching on C++20 and add some CI builds for C++20.
  * Bugfix: Fix typo in C++20 detection on MSVC.
  * Bugfix: An issue where the detection of RTTI being disabled on certain MSVC platforms did not disable the use of dynamic cast calls.
  * Bugfix: Resolve strict-overflow warning on some GCC compilers.
  * Backend: Add additional tests concerning the use of aliases for option groups in config files.
  * Build: Add support for testing in meson and cleanup symbolic link generation.
  * Build: Support building in WebAssembly.
* Mon Nov 22 2021 Haochuan Chen <yjcoshc@mail.nankai.edu.cn>
- Build doc package
- Include pkgconfig file
- Disable the build of examples
- Change the directory of cmake files to %%{_datadir}/cmake
- Use the upstream name for source and building, and keep the
  package name lowercase
- Update to version 2.1.2
  * Use main for the main branch of the repository
  * Bugfix(cmake): Enforce at least C++11 when using CMake target
  * Build: Don't run doxygen and CTest includes if a submodule
  * Build: Avoid a warning on CMake 3.22
  * Build: Support compiling the tests with an external copy of Catch2
* Thu Oct  8 2020 Jan Engelhardt <jengelh@inai.de>
- Trim conjecture from description and supply actual limits.
* Fri Sep 25 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Initial import of CLI11 1.9.1
